@@ -6,7 +6,7 @@ use Poz::Builder;
 use Exporter 'import';
 use Carp;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 our @EXPORT_OK = qw/z/;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -15,6 +15,7 @@ $Carp::Internal{'Poz'}++;
 $Carp::Internal{'Poz::Builder'}++;
 $Carp::Internal{'Poz::Types'}++;
 $Carp::Internal{'Poz::Types::scalar'}++;
+$Carp::Internal{'Poz::Types::null'}++;
 $Carp::Internal{'Poz::Types::string'}++;
 $Carp::Internal{'Poz::Types::number'}++;
 $Carp::Internal{'Poz::Types::object'}++;
@@ -147,6 +148,7 @@ Creates a new union schema object.
 L<Zod|https://zod.dev/>
 L<Poz::Builder>
 L<Poz::Types>
+L<Poz::Types::null>
 L<Poz::Types::string>
 L<Poz::Types::number>
 L<Poz::Types::object>
